@@ -23,9 +23,16 @@ class FunctionNotImplemented(Exception):
         return "This function is not yet available/completed."
 
 
-class UnknownRequestType(Exception):
+class UnsupportedRequestType(Exception):
     """
     If a requested body type is not mapped
     """
     def __str__(self):
         return "Unknown request type. Requests available: 'json', 'xml', 'text'."
+
+class UnsupportedBodyType(Exception):
+    """
+    If a requested body type is not mapped
+    """
+    def __str__(self):
+        return "This type of body is not supported for this API call."
\ No newline at end of file
